Authors
-------

* `Steven Murray <https://github.com/steven-murray>`_

Comments, corrections and suggestions
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* `Chris Jordan <https://github.com/cjordan>`_
* `Jordan Mirocha <https://github.com/mirochaj>`_
